# Tensile testing with Doli

- Setup control box at instrument
  - General information
  - buttons F1..F3 correspond to three symbols above
  - PC-mode: use for control by PC
  - turn knob to get there and then press ESC to get move the control from the handheld to the PC
- Start Software and hope that LAN connection works
  - otherwise retry
- Button Bike "Travel order"
  - distance-controlled, relative: 100mm with 100mm/min
  - direction clear
- Measure the sample:
  - |width||
  - |thickness||
- Mount sample: top first and then move into bottom
- Button Setup experiment: Hammer button
  - "Test procedure, speeds", "End of test" most important
  - Switch from F0->F1 confusing
  - choose F0 as max force
  - Example speeds:
    - metals=0.5mm/min
    - polymers=5mm/min
  - Adopt path: "Store data to"
- all 3 tare-buttons should  be pressed
- Button Traffic-Light: start experiments
- Button Diagram (one line)
  - open & close: rescale graph
- After test: Travel order
  - go back relative to 0
- After all is done
  - Close all wedges softly
  - drive back to touch almost: s=35mm
- Plot: click on series to plot all
  - double click on test
  - export by right click in graph and then copy-to-txt
  - Results in C:\Versuchsergebnisse

Author: Steffen Brinckmann, IMD-1, FZJ
<!--- version:1.0 |filename|| -->
